==> openshift-model-config-6.8.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterConditionFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterConditionFluent<A extends ClusterConditionFluent<A>> extends BaseFluent<A>{
  public ClusterConditionFluent() {
  }
  public ClusterConditionFluent(ClusterCondition instance) {
    instance = (instance != null ? instance : new ClusterCondition());

    if (instance != null) {
      this.withPromql(instance.getPromql());
      this.withType(instance.getType());
      this.withPromql(instance.getPromql());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private PromQLClusterConditionBuilder promql;
  private String type;
  private Map<String,Object> additionalProperties;
  public PromQLClusterCondition buildPromql() {
    return this.promql!=null ?this.promql.build():null;
  }
  public A withPromql(PromQLClusterCondition promql) {
    _visitables.get("promql").remove(this.promql);
    if (promql!=null){ this.promql= new PromQLClusterConditionBuilder(promql); _visitables.get("promql").add(this.promql);} else { this.promql = null; _visitables.get("promql").remove(this.promql); } return (A) this;
  }
  public boolean hasPromql() {
    return this.promql != null;
  }
  public A withNewPromql(String promql) {
    return (A)withPromql(new PromQLClusterCondition(promql));
  }
  public PromqlNested<A> withNewPromql() {
    return new PromqlNested(null);
  }
  public PromqlNested<A> withNewPromqlLike(PromQLClusterCondition item) {
    return new PromqlNested(item);
  }
  public PromqlNested<A> editPromql() {
    return withNewPromqlLike(java.util.Optional.ofNullable(buildPromql()).orElse(null));
  }
  public PromqlNested<A> editOrNewPromql() {
    return withNewPromqlLike(java.util.Optional.ofNullable(buildPromql()).orElse(new PromQLClusterConditionBuilder().build()));
  }
  public PromqlNested<A> editOrNewPromqlLike(PromQLClusterCondition item) {
    return withNewPromqlLike(java.util.Optional.ofNullable(buildPromql()).orElse(item));
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterConditionFluent that = (ClusterConditionFluent) o;
    if (!java.util.Objects.equals(promql, that.promql)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(promql,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (promql != null) { sb.append("promql:"); sb.append(promql + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class PromqlNested<N> extends PromQLClusterConditionFluent<PromqlNested<N>> implements Nested<N>{
    PromqlNested(PromQLClusterCondition item) {
      this.builder = new PromQLClusterConditionBuilder(this, item);
    }
    PromQLClusterConditionBuilder builder;
    public N and() {
      return (N) ClusterConditionFluent.this.withPromql(builder.build());
    }
    public N endPromql() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/ClusterConditionFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterConditionFluent<A extends ClusterConditionFluent<A>> extends BaseFluent<A>{
  public ClusterConditionFluent() {
  }
  
  public ClusterConditionFluent(ClusterCondition instance) {
    this.copyInstance(instance);
  }
  private PromQLClusterConditionBuilder promql;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterCondition instance) {
    instance = (instance != null ? instance : new ClusterCondition());
  
    if (instance != null) {
        this.withPromql(instance.getPromql());
        this.withType(instance.getType());
        this.withPromql(instance.getPromql());
        this.withType(instance.getType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public PromQLClusterCondition buildPromql() {
    return this.promql!=null ?this.promql.build():null;
  }
  
  public A withPromql(PromQLClusterCondition promql) {
    _visitables.get("promql").remove(this.promql);
    if (promql!=null){ this.promql= new PromQLClusterConditionBuilder(promql); _visitables.get("promql").add(this.promql);} else { this.promql = null; _visitables.get("promql").remove(this.promql); } return (A) this;
  }
  
  public boolean hasPromql() {
    return this.promql != null;
  }
  
  public A withNewPromql(String promql) {
    return (A)withPromql(new PromQLClusterCondition(promql));
  }
  
  public PromqlNested<A> withNewPromql() {
    return new PromqlNested(null);
  }
  
  public PromqlNested<A> withNewPromqlLike(PromQLClusterCondition item) {
    return new PromqlNested(item);
  }
  
  public PromqlNested<A> editPromql() {
    return withNewPromqlLike(java.util.Optional.ofNullable(buildPromql()).orElse(null));
  }
  
  public PromqlNested<A> editOrNewPromql() {
    return withNewPromqlLike(java.util.Optional.ofNullable(buildPromql()).orElse(new PromQLClusterConditionBuilder().build()));
  }
  
  public PromqlNested<A> editOrNewPromqlLike(PromQLClusterCondition item) {
    return withNewPromqlLike(java.util.Optional.ofNullable(buildPromql()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterConditionFluent that = (ClusterConditionFluent) o;
    if (!java.util.Objects.equals(promql, that.promql)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(promql,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (promql != null) { sb.append("promql:"); sb.append(promql + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class PromqlNested<N> extends PromQLClusterConditionFluent<PromqlNested<N>> implements Nested<N>{
    PromqlNested(PromQLClusterCondition item) {
      this.builder = new PromQLClusterConditionBuilder(this, item);
    }
    PromQLClusterConditionBuilder builder;
    
    public N and() {
      return (N) ClusterConditionFluent.this.withPromql(builder.build());
    }
    
    public N endPromql() {
      return and();
    }
    
  
  }

}
